This is the mail archive of the fortran@gcc.gnu.org mailing list for the GNU Fortran project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch, fortran, committed] Fix gfortran.h "obsolescent" comments.


The correct term for GFC_STD_F95_OBS features is "obsolescent", not "obsolete" -- they are still included as part of the language, and thus the latter is not merely incorrect but is misleading. This patch fixes the relevant comments in gfortran.h.

------------------------------------------------------------------
2007-03-24  Brooks Moses  <brooks.moses@codesourcery.com>

* gfortran.h: Edit comments on GFC_STD_*.

------------------------------------------------------------------

Tested with "make" on i686-pc-linux-gnu; committed to mainline as obvious.

- Brooks
Index: gfortran.h
===================================================================
--- gfortran.h	(revision 123170)
+++ gfortran.h	(working copy)
@@ -99,11 +99,14 @@
 #define GFC_STD_LEGACY		(1<<6) /* Backward compatibility.  */
 #define GFC_STD_GNU		(1<<5)    /* GNU Fortran extension.  */
 #define GFC_STD_F2003		(1<<4)    /* New in F2003.  */
-/* Note that no features were obsoleted nor deleted in F2003.  */
+/* Note that no additional features were deleted or made obsolescent
+   in F2003.  */
 #define GFC_STD_F95		(1<<3)    /* New in F95.  */
 #define GFC_STD_F95_DEL		(1<<2)    /* Deleted in F95.  */
-#define GFC_STD_F95_OBS		(1<<1)    /* Obsoleted in F95.  */
-#define GFC_STD_F77		(1<<0)    /* Up to and including F77.  */
+#define GFC_STD_F95_OBS		(1<<1)    /* Obsolescent in F95.  */
+#define GFC_STD_F77		(1<<0)    /* Included in F77, but not
+					     deleted or obsolescent in
+					     later standards.  */
 
 /* Bitmasks for the various FPE that can be enabled.  */
 #define GFC_FPE_INVALID    (1<<0)

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]